#!/usr/bin/perl
#
#	Program.:	hwdispatch.pl
#	Author..:	Gary C. Heller
#	Date....:	11-6-1997
#	Descrip.:	Send a file as a fax off the commandline
#	Version.:	1.0
#
#
#	ARGS:	-c Tel number(s)
#			-Z Subject
#			-C Name of template coverpage
#			-p Priority
#			-F From name
#			-T To name
#			-FF From Fax
#			-FV From Voice
#			-DA Del After
#			-PA Print After
#			-BN Current Basename
#			-U	Userid
#			{file1 file2 file3 etc etc }
#
use	Getopt::Std;
use	FileHandle;

#
#	THis script is called with the following args:
#	t = telnum, Z = subject, C = coverpage or NOCOVER, F = from_name,
#	T = to_name, p = Priority, U = userid, i = ignore missing files
#
$opt_h = "";
$tel_num = "";
$subj = "NO SUBJECT GIVEN";
$coverp = "NOCOVER";
$from_name = "";
$from_tel = "";
$from_fax = "";
$to_name = "";
$hw_root = "";
$param = "";
$missing_ok = 0;
$priority = 0;
$argc = @ARGV;
$userid = "$<";

getopts("ht:Z:C:F:T:p:U:i");

sub	usage()
{
	print "USAGE:  hwdispatch.pl {params}\n";
	print "   Where { params } are:\n";
	print "\t-t tel_num\n";
	print "\t-Z Subject\n";
	print "\t-C Coverpage_filename (or NOCOVER)\n";
	print "\t-F From_name\n";
	print "\t-T To_name\n";
	print "\t-p Priority [0-5] (0 is higher)\n";
	print "\t-U UserID\n";
	print "\tfiles Space-separated filenames to convert and send\n";
	print "NOTE:  You must quote any arguments that contain spaces\n";
	print "\n";
}

sub	set_hw_root()
{
	if (! -f "/etc/HotWire" ) {
		print "\nHotWire: No license file - can't continue!\n";
		exit 2;
		}
	$ifs = FileHandle->new();
	open($ifs, "/etc/HotWire") || die "HotWire: Can't open license file!";
	$hw_root = <$ifs>;
	$ifs->close();
	chomp($hw_root);
}
	
sub	ldconfig()
{
	if (! $hw_root ) {
		set_hw_root();
		}
	$ifs = FileHandle->new();
	$hw_config = $hw_root . "/config";
	open($ifs, $hw_config) || die "HotWire ERROR: Can't open $hw_config file!";
	while ($line = <$ifs>) {
		if ( $line =~ /^#/ ) {
			next;
			}
		chop($line);
		($param, $val) = split(' ', $line, 2);
		$cfg{$param} = $val;
		}
}

if ($opt_h || $argc == 0 ) {
	print "\nhwdispatch: Wrong number of arguments\n";
	usage();
	exit 1;
	}

#
#	Load up configuration
#
ldconfig();

if (! $opt_t ) {
	print "\nhwdispatch: You MUST supply the '-t tel_num' option\n";
	usage();
	exit 3;
	}
if (! $opt_T ) {
	print "\nhwdispatch: You MUST supply the '-t tel_num' option\n";
	usage();
	exit 3;
	}
$tel_num = $opt_t;

if (defined($opt_Z) ) {
	$subj = $opt_Z;
	}

if ( defined($opt_C) ) {
	$coverp = $opt_C;
	}

if (defined($from_name) ) {
	$from_name = $opt_F;
	}

if (defined($to_name) ) {
	$to_name = $opt_T;
	}

if (defined($opt_p) ) {
	$priority = $opt_p;
	}

if ($opt_U) {
	$userid = $opt_U;
	}

if ( defined($opt_i) ) {
	$missing_ok = 1;
	}
#
#	Gather list of files to send
#
$filecount = 0;
foreach $file ( @ARGV ) {
	if ( -f $file || (! -f $file && $missing_ok)  ) {
		if (-f $file) {
			push @flist, $file;
			$filecount++;
			print "Queueing file: $file\n";
			}
		}
	else
		{
		print "Can't open file: $file\n";
		if ($missing_ok == 0) {
			die "hwdispatch: Can't open $file - aborting!";
			}
		}
	}
#
#	Life is good, now we need to determine the BASENAME
#
	open($ifs, "ls -r -1 $hw_root/send/status | head -1 |");
	$basename = <$ifs>;
	$ifs->close();
	chop($basename);
	if (!defined($basename) || !$basename) {
		$basename = "00000";
		}
	$basename++;
#
#	Get the temp filename
#
$tmp_file = "fax" . "$$" . "_" . "$userid";
$cmd = $hw_root . "/bin/tfaxshell ";
$cmd .= $tmp_file;
$cmd .= " -c " . "\"$tel_num\"";
$cmd .= " -BN " . $basename;
$cmd .= " -Z " . "\"$subj\"";
$cmd .= " -C " . "\"$coverp\"";
$cmd .= " -p " . "\"$priority\"";
$cmd .= " -T " . "\"$to_name\"";
$cmd .= " -F " . "\"$from_name\"";
$cmd .= " -U " . "\"$userid\"";
$cmd .= " ";	# Must have this here.
$cmd .= join(' ', @flist);

#
#	Now the command is built up, execute it
#
# print "COMMAND: $cmd\n";
$rc = system($cmd);
exit $rc;
