#!/usr/bin/perl
#
#	Program.:	hwdispatch.pl
#	Author..:	Gary C. Heller
#	Date....:	11-6-1997
#	Descrip.:	Send a file as a fax off the commandline
#	Version.:	1.0
#
#
#	ARGS:
#      	-t  Tel number(s)
#       -Z  Subject
#       -C  Name of template coverpage
#		  	-F  From name
#		  	-T  To name
#		  	-p  Priority
#       -D  Delete After (yes, no)
#       -R  Print After (yes, no)
#       -d  Modem Port (ttyS0, ttyS1, ttyS2, ttyS3)
#       -r  Resolution (std, fine)
#       -m  Retries
#       -U  Userid
# 			 {file1 file2 file3 etc etc }
#

use	Getopt::Std;
use	FileHandle;

#
#	THis script is called with the following args:
# t = telnum, Z = subject, C = coverpage or NOCOVER, F = from_name,
# T = to_name, p = priority, D = Delete_after, R = print_after,
# d = modem_Port, r = resolution,  m = Retries, U = userid,
# i = ignore missing files,
#

$opt_h = "";
$tel_num = "";
$subj = "NO SUBJECT GIVEN";
$coverp = "NOCOVER";
$from_name = "";
$to_name = "";
$priority = 0;
$delete_after = "no";
$print_after = "no";
$modem_port = "";
$resolution = "std";
$retries = 3;
$hw_root = "";
$param = "";
$missing_ok = 0;
$argc = @ARGV;
$userid = "$<";

getopts("ht:Z:C:F:T:p:D:R:d:r:m:U:i");

sub	usage()
{
	print "USAGE:  hwdispatch.pl {params}\n";
	print "   Where { params } are:\n";
	print "\t-t tel_num\n";
	print "\t-Z Subject\n";
	print "\t-C Coverpage_filename (or NOCOVER)\n";		
  print "\t-F From_name\n";
	print "\t-T To_name\n";
  print "\t-p Priority [0-5] (0 is higher)\n";
  print "\t-D Delete After [yes, no]\n";
	print "\t-R Print After [yes, no]\n";		
  print "\t-d Modem Port [ttyS0, ttyS1, ttyS2, ttyS3]\n";
  print "\t-r Resolution [std, fine]\n";
  print "\t-m Reties [0-6]\n";
  print "\t-U UserID\n";
	print "\tfiles Space-separated filenames to convert and send\n";
	print "NOTE:  You must quote any arguments that contain spaces\n";
	print "\n";
}

sub	set_hw_root()
{
	if (! -f "/etc/HotWire" ) {
		print "\nHotWire: No license file - can't continue!\n";
		exit 2;
	}

	$ifs = FileHandle->new();
	open($ifs, "/etc/HotWire") || die "HotWire: Can't open license file!";
	$hw_root = <$ifs>;
	$ifs->close();
	chomp($hw_root);
}
	
sub	ldconfig()
{
	if (! $hw_root ) {
		set_hw_root();
	}

#  Multiple config files
#
  if ( $modem_port eq 'ttyS0') {
     $hw_config = $hw_root . "/config.ttyS0";
  } elsif ( $modem_port eq 'ttyS1') {
     $hw_config = $hw_root . "/config.ttyS1";
  }	elsif ( $modem_port eq 'ttyS2') {
     $hw_config = $hw_root . "/config.ttyS2";
  }	elsif ( $modem_port eq 'ttyS3') {
     $hw_config = $hw_root . "/config.ttyS3";
  }	elsif ( $modem_port eq 'modem') {
     $hw_config = $hw_root . "/config.modem";
  }	else  {
     $hw_config = $hw_root . "/config.ttyS1";
	}

	$ifs = FileHandle->new();
	open($ifs, $hw_config) || die "HotWire ERROR: Can't open $hw_config file!";

	while ($line = <$ifs>) {
	
  	if ( $line =~ /^#/ ) {
  			next;
		}

		chop($line);
		($param, $val) = split(' ', $line, 2);
		$cfg{$param} = $val;
	}
}

if ($opt_h || $argc == 0 ) {
  	print "\nhwdispatch: Wrong number of arguments\n";
	 usage();
	 exit 1;
}

#
#	Load up configuration
#

if ( defined($opt_d) ) {
	$modem_port = $opt_d;
} 

ldconfig();

if (! $opt_t ) {
	  print "\nhwdispatch: You MUST supply the '-t tel_num' option\n";
	  usage();
	  exit 3;
} else {
    $tel_num = $opt_t;
}

#if (! $opt_T ) {
#	print "\nhwdispatch: You MUST supply the '-t tel_num' option\n";
#	usage();
#	exit 3;
#	}

if ( defined($opt_Z) ) {
   $subj = $opt_Z;
}

if ( defined($opt_C) ) {
	 $coverp = $opt_C;
}

if ( defined($opt_F) ) {
	 $from_name = $opt_F;
}

if ( defined($opt_T) ) {
	 $to_name = $opt_T;
}

if ( defined($opt_p) ) {
	 $priority = $opt_p;
}

if ( defined($opt_D) ) {
	 $delete_after = $opt_D;
}

if ( defined($opt_R) ) {
	 $print_after = $opt_R;
}

if ( defined($opt_r) ) {
	 $resolution = $opt_r;
}

if ( defined($opt_m) ) {
	 $retries = $opt_m;
}

if ( defined($opt_U) ) {
	 $userid = $opt_U;
}

if ( defined($opt_i) ) {
	 $missing_ok = 1;
}

#
#	Gather list of files to send
#

$filecount = 0;
foreach $file ( @ARGV ) {
	if ( -f $file || (! -f $file && $missing_ok) ) {
     	if (-f $file) {
    			push @flist, $file;
		    	$filecount++;
#    			print "Queueing file: $file\n";
		  }
	} else {
   		print "Can't open file: $file\n";
  	  if ($missing_ok == 0) {
    	    die "hwdispatch: Can't open $file - aborting!";
    	}
  }
}

#
#	Life is good, now we need to determine the BASENAME
#
	open($ifs, "ls -r -1 $hw_root/send/status | head -1 |");
	$basename = <$ifs>;
	$ifs->close();
	chop($basename);

	if (!defined($basename) || !$basename) {
		$basename = "00000";
	}

	$basename++;

#
#	Get the temp filename
#

$tmp_file = "fax" . "$$" . "_" . "$userid";
$cmd = $hw_root . "/bin/tfaxshell ";
$cmd .= $tmp_file;
$cmd .= " -c  " . "\"$tel_num\"";
$cmd .= " -Z  " . "\"$subj\"";
$cmd .= " -C  " . "\"$coverp\"";
$cmd .= " -F  " . "\"$from_name\"";
$cmd .= " -T  " . "\"$to_name\"";
$cmd .= " -p  " . "\"$priority\"";
$cmd .= " -DA " . "\"$delete_after\"";
$cmd .= " -PA " . "\"$print_after\"";
$cmd .= " -d  " . "\"$modem_port\"";
$cmd .= " -r  " . "\"$resolution\"";
$cmd .= " -m  " . "\"$retries\"";
$cmd .= " -BN " . $basename;
$cmd .= " -U  " . "\"$userid\"";
$cmd .= " ";	# Must have this here.
$cmd .= join(' ', @flist);

#debug
#print "*option1: $tel_num $from_name $to_name $subj\n";
#print "*option2: $modem_port $coverp $retries $resolution\n";
#print "*option3: $priority $delete_after $print_after $basename\n";
#print "*files: @flist\n";

#
#	Now the command is built up, execute it
#
# print "COMMAND: $cmd\n";
$rc = system($cmd);
exit $rc;
